import java.util.List;
import junit.framework.Assert;
import org.junit.After;
import org.junit.AfterClass;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;
import static org.junit.Assert.*;

public class CitatDaoTest {
    private CitatDao dao;
    
    @Before
    public void setUp() {
        dao = new PamatovyCitatDao();
        Citat citat1 = new Citat();
        citat1.setId(1);
        citat1.setAutor("Richard P. Feynman");
        citat1.setText("All mass is interaction.");
        citat1.setZdroj("WikiQuote");
        dao.save(citat1);

        
        Citat citat2 = new Citat();
        citat2.setId(2);
        citat2.setAutor("Rene Descartes");
        citat2.setText("Myslim, teda som.");
        citat2.setZdroj("Internety");
        dao.save(citat2);
        
        Citat citat3 = new Citat();
        citat3.setId(3);
        citat3.setAutor("Pista Lakatos");
        citat3.setText("For me, behind me.");
        citat3.setZdroj("TV Lokal");
        dao.save(citat3);

        Citat citat4 = new Citat();
        citat4.setId(4);
        citat4.setAutor("Rene Descartes");
        citat4.setText("Nestaci mat dobru mysel, dolezite je dobre ju pouzivat .");
        citat4.setZdroj("WikiQuote");        
        dao.save(citat4);
        
    }
    
    @Test
    public void testNajdiPodlaId() {
        
        Citat citat = dao.najdiPodlaId(1);
        assertEquals("Richard P. Feynman", citat.getAutor());
        assertEquals("All mass is interaction.", citat.getText());
    }
    
    @Test
    public void testUloz() {
        Citat c = new Citat();
        c.setAutor("Pista Lakatos");
        c.setId(10);
        c.setText("The battery has just arrived");
        c.setZdroj("TV Lokal");
        
        dao.save(c);
        
        Citat citat = dao.najdiPodlaId(10);
        assertEquals("The battery has just arrived", citat.getText());
        assertEquals("TV Lokal", citat.getZdroj());
            
    }

    @Test
    public void testNajdiPodlaAutora() {
        List<Citat> citaty = dao.najdiPodlaAutora("Rene Descartes");
        assertEquals(2, citaty.size());
    }

    @Test
    public void testNajdiPodlaZdroja() {
        List<Citat> citaty = dao.najdiPodlaZdroja("WikiQuote");
        assertEquals(2, citaty.size());        
    }

    @Test
    public void testVymaz() {
        Citat citat = new Citat();
        citat.setId(4);
        
        dao.delete(citat);
        Citat vymazanyCitat = dao.najdiPodlaId(4);
        assertNull(vymazanyCitat);
    }
    
    
}
